@@ -220,7 +220,8 @@ def format_autolab_json(data, indent=None):
 
             d = {'passed': pass_}
             if not pass_:
-                d['hint'] = "<br>".join( val['stderr'].strip().splitlines() )
+                d['hint'] = val['stderr']
+                # d['hint'] = "<br>".join( val['stderr'].strip().splitlines() )
 
 
             rs[item_name] = d
